#!/bin/sh
# Licensed Materials - Property of IBM
#
# (C) Copyright IBM Corp. 2003, 2011 All Rights Reserved
#
# US Government Users Restricted Rights - Use, duplicate or
# disclosure restricted by GSA ADP Schedule Contract with
# IBM Corp.

TC_DB=$1
BACKUP_DIR=$2
BACKUP_INFO_FILE=$3

if [ -z $TC_DB ]; then
   TC_DB=tc
fi

# set up user profile to execute DB2 command
DBENV_FILE=/opt/ibm/director/lwi/conf/overrides/dbvariables.properties
if [ -e "$DBENV_FILE" ] ; then
  . "$DBENV_FILE"
  if [ ! "$DIRDB2INST" = "" ] ; then
      . "$DIRDB2INST/db2profile"
  fi
fi

. /opt/ibm/director/bin/setup

rm $BACKUP_INFO_FILE

# connect to db2, quiesce database
echo "Quiesce database ..."
echo "db2 connect TO $TC_DB"
db2 -tf "db2/temp-connect.sql" -z "$BACKUP_INFO_FILE"
if [ "$?" -ne "0" ] ; then
    exit 1
fi
db2 QUIESCE DATABASE IMMEDIATE FORCE CONNECTIONS
db2 TERMINATE
db2 -tf "db2/temp-deactivate.sql"

rm $BACKUP_INFO_FILE

#backup database
echo "Database backup directory: $BACKUP_DIR"
echo "Backing up database $TC_DB ..."
db2 -tf "db2/temp-backup.sql" -z "$BACKUP_INFO_FILE"
backupReturnCode=$?
echo "Database backup finished with exit code $backupReturnCode, check $BACKUP_INFO_FILE for the details"

# connect to db2, unquiesce database
echo "Unquiesce database ..."
echo "db2 connect TO $TC_DB"
db2 -tf "db2/temp-connect.sql"
if [ "$?" -ne "0" ] ; then
    exit 1 
fi
db2 UNQUIESCE DATABASE
db2 TERMINATE

if [ $backupReturnCode -ne "0" ] ; then
    exit 1
fi

exit 0
