@echo off
rem
rem Licensed Materials - Property of IBM
rem 5724-F75
rem (C) Copyright IBM Corp.  2009, 2010
rem All Rights Reserved
rem US Government Users Restricted Rights -Use, duplication or
rem disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
rem
rem
@echo off

set DB2_DB_NAME=%1
set DB2_DB_HOST_NAME=%2
set DB2_DB_PORT=%3
set DB2_SERVER_LOCAL=%4
set DB2_DBID_IS_ADMINID=%5
SHIFT /5
set DB2_SQLLIB_HOME=~%fs5
set SCRIPT_DIR=%~sdp0

set ERR_DB2_CONFIG=220

rem check if database already exists
echo connect to %DB2_DB_NAME% 
set DBCOMMAND="%SCRIPT_DIR%temp-connect.sql"
db2 -tf "%DBCOMMAND%"
if errorlevel 1 goto dbsetup
goto updatedbcfg
  
:dbsetup
rem setup remote server connection
echo catalog tcpip node %DB2_DB_NAME% remote %DB2_DB_HOST_NAME% server %DB2_DB_PORT%
db2 catalog tcpip node %DB2_DB_NAME% remote %DB2_DB_HOST_NAME% server %DB2_DB_PORT%

rem attempt to create the database for local server case
echo create database %DB2_DB_NAME% automatic storage yes using codeset UTF-8 territory US PAGESIZE 8192
db2 create database %DB2_DB_NAME% automatic storage yes using codeset UTF-8 territory US PAGESIZE 8192
if errorlevel 1 goto dbattach
goto common

:dbattach
rem for remote databases, attach before creating the database
echo attach to %DB2_DB_NAME%
set DBCOMMAND="%SCRIPT_DIR%temp-attach.sql"
db2 -tf "%DBCOMMAND%"
if errorlevel 1 exit 1

rem attempt to create the database for remote server case  
echo create database %DB2_DB_NAME% automatic storage yes using codeset UTF-8 territory US PAGESIZE 8192
db2 create database %DB2_DB_NAME% automatic storage yes using codeset UTF-8 territory US PAGESIZE 8192
rem don't exit if db already exists

rem catalog database that has been created on the server. 
echo catalog database %DB2_DB_NAME% at node %DB2_DB_NAME%
db2 catalog database %DB2_DB_NAME% at node %DB2_DB_NAME%
  
:common
echo connect to %DB2_DB_NAME% 
set DBCOMMAND="%SCRIPT_DIR%temp-connect.sql"
db2 -tf "%DBCOMMAND%"
if errorlevel 1 exit 1

:updatedbcfg	
rem echo updating db cfg for %DB2_DB_NAME% using applheapsz 4096
rem db2 update db cfg for %DB2_DB_NAME% using applheapsz 4096

rem echo updating db cfg for %DB2_DB_NAME% using stmtheap 3072
rem db2 update db cfg for %DB2_DB_NAME% using stmtheap 3072

echo updating db cfg for %DB2_DB_NAME% using logprimary 30
db2 update db cfg for %DB2_DB_NAME% using logprimary 30

echo updating db cfg for %DB2_DB_NAME% using logsecond 20
db2 update db cfg for %DB2_DB_NAME% using logsecond 20

rem echo updating db cfg for %DB2_DB_NAME% using database_memory 90000
rem db2 update db cfg for %DB2_DB_NAME% using database_memory 90000

rem echo Updating the db cfg for %DB2_DB_NAME% using maxappls 400
rem db2 update db cfg for %DB2_DB_NAME% using maxappls 400

rem echo updating db cfg for %DB2_DB_NAME% using app_ctl_heap_sz 2048
rem db2 update db cfg for %DB2_DB_NAME% using app_ctl_heap_sz 2048

echo updating db cfg for %DB2_DB_NAME% using locktimeout 120
db2 update db cfg for %DB2_DB_NAME% using locktimeout 120

echo db2 reorgchk update statistics on table all
db2 reorgchk update statistics on table all

echo updating db cfg for %DB2_DB_NAME% using auto_maint on immediate
db2 update db cfg for %DB2_DB_NAME% using auto_maint on immediate

echo updating db cfg for %DB2_DB_NAME% using auto_tbl_maint on immediate
db2 update db cfg for %DB2_DB_NAME% using auto_tbl_maint on immediate

echo updating db cfg for %DB2_DB_NAME% using auto_runstats on immediate
db2 update db cfg for %DB2_DB_NAME% using auto_runstats on immediate

:: Commented out the following since it might cause deadlock in some situations
::echo updating db cfg for %DB2_DB_NAME% using auto_stats_prof on immediate
::db2 update db cfg for %DB2_DB_NAME% using auto_stats_prof on immediate
::echo %ERRORLEVEL%

echo Reset the database connection
db2 connect reset

echo connect to %DB2_DB_NAME%
set DBCOMMAND="%SCRIPT_DIR%temp-connect.sql"
db2 -tf "%DBCOMMAND%"

echo bind to %DB2_DB_NAME%
db2 bind %DB2_SQLLIB_HOME%\bnd\@db2ubind.lst blocking all grant public

echo Create tablespaces 
set DBCOMMAND="%SCRIPT_DIR%tablespace.sql"
db2 -tvf "%DBCOMMAND%"
rem IF NOT %ERRORLEVEL% == 0 (
rem 
rem   echo Error creating tablespaces
rem   exit 1
rem 
rem )

rem Grant privileges to the db user
IF %DB2_DBID_IS_ADMINID% == true (
  GOTO end 
)

  echo grant dbadm on database to user 
  set DBCOMMAND="%SCRIPT_DIR%temp-grant1.sql"
  db2 -tf "%DBCOMMAND%"
  
  echo Granting use of tablespace IBM4KSPACE to user 
  set DBCOMMAND="%SCRIPT_DIR%temp-grant4k.sql"
  db2 -tf "%DBCOMMAND%"

  echo Granting use of tablespace IBM8KSPACE to user 
  set DBCOMMAND="%SCRIPT_DIR%temp-grant2.sql"
  db2 -tf "%DBCOMMAND%"

  echo Granting use of tablespace IBM16KSPACE to user 
  set DBCOMMAND="%SCRIPT_DIR%temp-grant3.sql"
  db2 -tf "%DBCOMMAND%"
  
  echo Granting use of tablespace IBM32KSPACE to user 
  set DBCOMMAND="%SCRIPT_DIR%temp-grant4.sql"
  db2 -tf "%DBCOMMAND%"

  echo Granting select on SYSIBM.SYSDUMMY1 to user
  set DBCOMMAND="%SCRIPT_DIR%temp-grant5.sql"
  db2 -tf "%DBCOMMAND%"
    
:end
rem echo Reset the database connection
rem db2 connect reset
rem echo %ERRORLEVEL%
db2 terminate
exit 0
