#!/bin/sh
# Licensed Materials - Property of IBM
#
# (C) Copyright IBM Corp. 2009, 2011 All Rights Reserved
#
# US Government Users Restricted Rights - Use, duplicate or
# disclosure restricted by GSA ADP Schedule Contract with
# IBM Corp.
 
ERR_NUM_PARAMS=201
ERR_DB2_PROFILE=205 
ERR_DB2_CONFIG=220 


if [ $# -ne 7 ]
then
  echo "Invalid number of arguments"
  exit $ERR_NUM_PARAMS
fi

DB2_DB_NAME=$1
DB2_DB_HOST_NAME=$2
DB2_DB_PORT=$3
DB2_SERVER_LOCAL=$4
DB2_DBID_IS_ADMINID=$5
shift 5
DB2_SQLLIB_HOME=$1
DIR_SQL_DIR=$2

DBENV_FILE=/opt/ibm/director/lwi/conf/overrides/dbvariables.properties
if [ -e "$DBENV_FILE" ] ; then
  . "$DBENV_FILE"
  if [ ! "$DIRDB2INST" = "" ] ; then
      . "$DIRDB2INST/db2profile"
  fi
fi

if [ -e "$DIR_SQL_DIR/db2/db2_setup.sh" ] ; then
  . "$DIR_SQL_DIR/db2/db2_setup.sh"
fi

echo "connect to $DB2_DB_NAME"
db2 -tf "$DIR_SQL_DIR/db2/temp-connect.sql"
EXIT_CODE=$?
if [ $EXIT_CODE -ne 0 ] ; 
then
  echo "catalog tcpip node $DB2_DB_NAME remote $DB2_DB_HOST_NAME server $DB2_DB_PORT"
  db2 catalog tcpip node $DB2_DB_NAME remote $DB2_DB_HOST_NAME server $DB2_DB_PORT
  #  EXIT_CODE=$?
  #  if [ $EXIT_CODE -ne 0 ]
  #  then
  #    exit $EXIT_CODE
  #  fi

  # if DB2 is local, try creating the database without explicit attach
  EXIT_CODE=0
  if [ $DB2_SERVER_LOCAL = "true" ] ;
  then  
    echo "create database $DB2_DB_NAME automatic storage yes using codeset UTF-8 territory US PAGESIZE 8192"
    db2 create database $DB2_DB_NAME automatic storage yes using codeset UTF-8 territory US PAGESIZE 8192
 
    EXIT_CODE=$?
  fi 

  # if above fails or if the DB2 server is remote, attach before trying create
  if [[ $EXIT_CODE -ne 0 || $DB2_SERVER_LOCAL = "false" ]] ;  
  then
    echo "attach to $DB2_DB_NAME"
    db2 -tf "$DIR_SQL_DIR/db2/temp-attach.sql"
    EXIT_CODE=$?
    if [ $EXIT_CODE -ne 0 ] ;
    then
      exit 1 
    fi
    
    echo "create database $DB2_DB_NAME automatic storage yes using codeset UTF-8 territory US PAGESIZE 8192"
    db2 create database $DB2_DB_NAME automatic storage yes using codeset UTF-8 territory US PAGESIZE 8192
    #  EXIT_CODE=$?
    #  if [ $EXIT_CODE -ne 0 ]
    #  then
    #    exit $EXIT_CODE
    #  fi

    #catalog database if we assume database has been created on the server. 
    echo "catalog database $DB2_DB_NAME at node $DB2_DB_NAME"
    db2 catalog database $DB2_DB_NAME at node $DB2_DB_NAME 
  fi
  
  echo "connect to $DB2_DB_NAME"
  db2 -tf "$DIR_SQL_DIR/db2/temp-connect.sql"
  EXIT_CODE=$?
  if [ $EXIT_CODE -ne 0 ] ; 
  then
    exit 1 
  fi	
fi	

echo "setting params"

#echo "updating the db cfg for $DB2_DB_NAME using applheapsz 4096"
#db2 update db cfg for $DB2_DB_NAME using applheapsz 4096

#echo "updating the db cfg for $DB2_DB_NAME using stmtheap 3072"
#db2 update db cfg for $DB2_DB_NAME using stmtheap 3072

echo "updating the db cfg for $DB2_DB_NAME using logprimary 30"
db2 update db cfg for $DB2_DB_NAME using logprimary 30

echo "updating the db cfg for $DB2_DB_NAME using logsecond 20"
db2 update db cfg for $DB2_DB_NAME using logsecond 20

#echo "updating the db cfg for $DB2_DB_NAME using database_memory 90000"
#db2 update db cfg for $DB2_DB_NAME using database_memory 90000

#echo "updating the db cfg for $DB2_DB_NAME using maxappls 400"
#db2 update db cfg for $DB2_DB_NAME using maxappls 400

#echo "updating the db cfg for $DB2_DB_NAME using app_ctl_heap_sz 2048"
#db2 update db cfg for $DB2_DB_NAME using app_ctl_heap_sz 2048

echo "updating the db cfg for $DB2_DB_NAME using locktimeout 120"
db2 update db cfg for $DB2_DB_NAME using locktimeout 120

echo "db2 reorgchk update statistics on table all"
db2 reorgchk update statistics on table all

echo "updating the db cfg for $DB2_DB_NAME using auto_maint on immediate"
db2 update db cfg for $DB2_DB_NAME using auto_maint on immediate

echo "updating the db cfg for $DB2_DB_NAME using auto_tbl_maint on immediate"
db2 update db cfg for $DB2_DB_NAME using auto_tbl_maint on immediate

echo "updating the db cfg for $DB2_DB_NAME using auto_runstats on immediate"
db2 update db cfg for $DB2_DB_NAME using auto_runstats on immediate

# Commented out the following since it might cause deadlock in some situations
#echo "updating the db cfg for $DB2_DB_NAME using auto_stats_prof on immediate"
#db2 update db cfg for $DB2_DB_NAME using auto_stats_prof on immediate
#echo $?

echo "Reset the database connection"
db2 connect reset

echo "connect to $DB2_DB_NAME"
db2 -tf "$DIR_SQL_DIR/db2/temp-connect.sql"
EXIT_CODE=$?
if [ $EXIT_CODE -ne 0 ]
then
  exit 1
fi

echo "bind $DB2_SQLLIB_HOME/bnd/@db2ubind.lst blocking all grant public"
db2 bind $DB2_SQLLIB_HOME/bnd/@db2ubind.lst blocking all grant public

echo "Create tablespaces"
db2 -tvf $DIR_SQL_DIR/db2/tablespace.sql
#EXIT_CODE=$?
#if [ $EXIT_CODE -ne 0 ]
#then
#  echo "Error Creating tablespaces, $EXIT_CODE"
#  exit $EXIT_CODE
#fi

# Grant privileges to the db user if it's not the instance owner
if [ $DB2_DBID_IS_ADMINID != "true" ]
then
  echo "Granting DBADM on database $DB2_DB_NAME to user"
  db2 -tf "$DIR_SQL_DIR/db2/temp-grant1.sql"
  
  echo "Granting use of tablesspace IBM4KSPACE to user"
  db2 -tf "$DIR_SQL_DIR/db2/temp-grant4k.sql"
  
  echo "Granting use of tablesspace IBM8KSPACE to user"
  db2 -tf "$DIR_SQL_DIR/db2/temp-grant2.sql"

  echo "Granting use of tablesspace IBM16KSPACE to user"
  db2 -tf "$DIR_SQL_DIR/db2/temp-grant3.sql"

  echo "Granting use of tablespace IBM32KSPACE to user"
  db2 -tf "$DIR_SQL_DIR/db2/temp-grant4.sql"

  echo "Granting select on SYSIBM.SYSDUMMY1 to user"
  db2 -tf "$DIR_SQL_DIR/db2/temp-grant5.sql"
fi

#echo "Reset database connection"
#db2 connect reset
#echo $?

db2 terminate
exit 0
