#!/bin/sh
# Licensed Materials - Property of IBM
#
# (C) Copyright IBM Corp. 2011, 2012 All Rights Reserved
#
# US Government Users Restricted Rights - Use, duplicate or
# disclosure restricted by GSA ADP Schedule Contract with
# IBM Corp.
 
ERR_NUM_PARAMS=201
ERR_DB2_PROFILE=205 
ERR_DB2_CONFIG=220 


if [ $# -ne 8 ]
then
  echo "Invalid number of arguments"
  exit $ERR_NUM_PARAMS
fi

DB2_DB_NAME=$1
DB2_DB_HOST_NAME=$2
DB2_DB_PORT=$3
DB2_SERVER_LOCAL=$4
DB2_DBID_IS_ADMINID=$5
shift 5
DB2_SQLLIB_HOME=$1
DIR_SQL_DIR=$2
DB2_DB_LOCATION=$3

DBENV_FILE=/opt/ibm/director/lwi/conf/overrides/dbvariables.properties
if [ -e "$DBENV_FILE" ] ; then
  . "$DBENV_FILE"
  if [ ! "$DIRDB2INST" = "" ] ; then
      . "$DIRDB2INST/db2profile"
  fi
fi

if [ -e "$DIR_SQL_DIR/db2/db2_setup.sh" ] ; then
  . "$DIR_SQL_DIR/db2/db2_setup.sh"
fi

EXIT_CODE=0
# update the location where the default database should go
if [ $DB2_DB_LOCATION != "false" ]
then 
  echo "update dbm cfg using DFTDBPATH $DB2_DB_LOCATION"
  db2 update dbm cfg using DFTDBPATH $DB2_DB_LOCATION
  if [ $EXIT_CODE -ne 0 ]
  then
    exit 1 
  fi

  db2 force application all

  echo "stop database manager"
  db2 stop database manager
  if [ $EXIT_CODE -ne 0 ]
  then
    exit 1 
  fi
  
  echo "start database manager"
  db2 start database manager
  if [ $EXIT_CODE -ne 0 ]
  then
    exit 1 
  fi
fi

echo "connect to $DB2_DB_NAME"
db2 -tf "$DIR_SQL_DIR/db2/temp-connect.sql"
EXIT_CODE=$?
if [ $EXIT_CODE -ne 0 ] 
then
  echo "catalog tcpip node $DB2_DB_NAME remote $DB2_DB_HOST_NAME server $DB2_DB_PORT"
  db2 catalog tcpip node $DB2_DB_NAME remote $DB2_DB_HOST_NAME server $DB2_DB_PORT
  #  EXIT_CODE=$?
  #  if [ $EXIT_CODE -ne 0 ]
  #  then
  #    exit $EXIT_CODE
  #  fi
  
  echo "create database $DB2_DB_NAME automatic storage yes using codeset UTF-8 territory US PAGESIZE 8192 restrictive"
  db2 create database $DB2_DB_NAME automatic storage yes using codeset UTF-8 territory US PAGESIZE 8192 restrictive
  EXIT_CODE=$?
  if [ $EXIT_CODE -ne 0 ] 
  then
    echo "attach to $DB2_DB_NAME"
    db2 -tf "$DIR_SQL_DIR/db2/temp-attach.sql"
    EXIT_CODE=$?
    if [ $EXIT_CODE -ne 0 ]
    then
      exit 1 
    fi
    
    echo "create database $DB2_DB_NAME automatic storage yes using codeset UTF-8 territory US PAGESIZE 8192 restrictive"
    db2 create database $DB2_DB_NAME automatic storage yes using codeset UTF-8 territory US PAGESIZE 8192 restrictive
    #  EXIT_CODE=$?
    #  if [ $EXIT_CODE -ne 0 ]
    #  then
    #    exit $EXIT_CODE
    #  fi

    #catalog database if we assume database has been created on the server. 
    echo "catalog database $DB2_DB_NAME at node $DB2_DB_NAME"
    db2 catalog database $DB2_DB_NAME at node $DB2_DB_NAME 
  fi
  
  echo "connect to $DB2_DB_NAME"
  db2 -tf "$DIR_SQL_DIR/db2/temp-connect.sql"
  EXIT_CODE=$?
  if [ $EXIT_CODE -ne 0 ]
  then
    exit 1 
  fi	
fi	

echo "Setting params"

echo "Updating the db cfg for $DB2_DB_NAME using applheapsz automatic"
db2 update db cfg for $DB2_DB_NAME using applheapsz automatic

echo "Updating the db cfg for $DB2_DB_NAME using stmtheap automatic"
db2 update db cfg for $DB2_DB_NAME using stmtheap automatic

echo "Updating the db cfg for $DB2_DB_NAME using logprimary 30"
db2 update db cfg for $DB2_DB_NAME using logprimary 30

echo "Updating the db cfg for $DB2_DB_NAME using logsecond 226"
db2 update db cfg for $DB2_DB_NAME using logsecond 226

echo "Updating the db cfg for $DB2_DB_NAME using database_memory automatic"
db2 update db cfg for $DB2_DB_NAME using database_memory automatic

echo "Updating the db cfg for $DB2_DB_NAME using maxappls automatic"
db2 update db cfg for $DB2_DB_NAME using maxappls automatic

echo "Updating the db cfg for $DB2_DB_NAME using self_tuning_mem on"
db2 update db cfg for $DB2_DB_NAME using self_tuning_mem on

echo "Updating the db cfg for $DB2_DB_NAME using avg_appls automatic"
db2 update db cfg for $DB2_DB_NAME using avg_appls automatic

#echo "Updating the db cfg for $DB2_DB_NAME using app_ctl_heap_sz 2048"
#db2 update db cfg for $DB2_DB_NAME using app_ctl_heap_sz 2048

echo "Updating the db cfg for $DB2_DB_NAME using locktimeout 120"
db2 update db cfg for $DB2_DB_NAME using locktimeout 120

echo "Updating db cfg for $DB2_DB_NAME using dbheap automatic"
db2 update db cfg for $DB2_DB_NAME using dbheap automatic

echo "Updating db cfg for $DB2_DB_NAME using locklist automatic"
db2 update db cfg for $DB2_DB_NAME using locklist automatic

echo "Updating db cfg for $DB2_DB_NAME using stat_heap_sz automatic"
db2 update db cfg for $DB2_DB_NAME using stat_heap_sz automatic

echo "Updating db cfg for $DB2_DB_NAME using stmtheap 8192 automatic"
db2 update db cfg for $DB2_DB_NAME using stmtheap 8192 automatic

echo "db2 reorgchk update statistics on table all"
db2 reorgchk update statistics on table all

echo "Updating the db cfg for $DB2_DB_NAME using auto_maint on immediate"
db2 update db cfg for $DB2_DB_NAME using auto_maint on immediate

echo "Updating the db cfg for $DB2_DB_NAME using auto_tbl_maint on immediate"
db2 update db cfg for $DB2_DB_NAME using auto_tbl_maint on immediate

echo "Updating the db cfg for $DB2_DB_NAME using auto_runstats on immediate"
db2 update db cfg for $DB2_DB_NAME using auto_runstats on immediate

echo "Updating the db cfg for $DB2_DB_NAME using auto_stmt_stats on"
db2 update db cfg for $DB2_DB_NAME using auto_stmt_stats on

echo "Updating the db cfg for $DB2_DB_NAME using auto_reorg on"
db2 update db cfg for $DB2_DB_NAME using auto_reorg on

echo "Updating the db cfg for $DB2_DB_NAME using pckcachesz automatic"
db2 update db cfg for $DB2_DB_NAME using pckcachesz automatic

echo "Updating db cfg for $DB2_DB_NAME using discover_db disable"
db2 update db cfg for $DB2_DB_NAME using discover_db disable

echo "Updating dbm cfg using discover known"
db2 update dbm cfg using discover known

echo "Updating dbm cfg using discover_inst disable"
db2 update dbm cfg using discover_inst disable

# Commented out the following since it might cause deadlock in some situations
#echo "Updating the db cfg for $DB2_DB_NAME using auto_stats_prof on immediate"
#db2 update db cfg for $DB2_DB_NAME using auto_stats_prof on immediate
#echo $?

echo "Reset the database connection"
db2 connect reset

echo "connect to $DB2_DB_NAME"
db2 -tf "$DIR_SQL_DIR/db2/temp-connect.sql"
EXIT_CODE=$?
if [ $EXIT_CODE -ne 0 ]
then
  exit 1
fi

echo "bind $DB2_SQLLIB_HOME/bnd/@db2ubind.lst blocking all grant public"
db2 bind $DB2_SQLLIB_HOME/bnd/@db2ubind.lst blocking all grant public

echo "Create tablespaces"
db2 -tvf $DIR_SQL_DIR/db2/tablespace.sql

echo "Setting AutoReorgPolicy"
db2 -tvf $DIR_SQL_DIR/db2/temp-setAutoReorgPolicy.sql

#EXIT_CODE=$?
#if [ $EXIT_CODE -ne 0 ]
#then
#  echo "Error Creating tablespaces, $EXIT_CODE"
#  exit $EXIT_CODE
#fi

# Do not need to grant extra privileges since the embedded DB2 user is instance owner

#echo "Reset database connection"
#db2 connect reset
#echo $?

db2 terminate

# Set DB2_WORKLOADTPM
$DB2_SQLLIB_HOME/adm/db2set DB2_WORKLOAD=TPM

exit 0
